@@ -1,15 +1,18 @@
 /* 
  * xendump.c 
  * 
- * Copyright (C) 2006, 2007, 2008 David Anderson
- * Copyright (C) 2006, 2007, 2008 Red Hat, Inc. All rights reserved.
+ * Copyright (C) 2006, 2007, 2008, 2009, 2010 David Anderson
+ * Copyright (C) 2006, 2007, 2008, 2009, 2010 Red Hat, Inc. All rights reserved.
  *
- * This software may be freely redistributed under the terms of the
- * GNU General Public License.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  */
 
 #include "defs.h"
@@ -120,8 +123,12 @@ xc_core_verify(char *file, char *buf)
 		clean_exit(1);
 	}
 
-	BCOPY(xcp, &xd->xc_core.header, 
-		sizeof(struct xc_core_header));
+	xd->xc_core.header.xch_magic = xcp->xch_magic;
+	xd->xc_core.header.xch_nr_vcpus = xcp->xch_nr_vcpus;
+	xd->xc_core.header.xch_nr_pages = xcp->xch_nr_pages;
+	xd->xc_core.header.xch_ctxt_offset = (ulong)xcp->xch_ctxt_offset;
+	xd->xc_core.header.xch_index_offset = (ulong)xcp->xch_index_offset;
+	xd->xc_core.header.xch_pages_offset = (ulong)xcp->xch_pages_offset;
 
         xd->flags |= (XENDUMP_LOCAL | XC_CORE_ORIG | XC_CORE_P2M_CREATE);
 
@@ -1033,13 +1040,13 @@ xendump_memory_dump(FILE *fp)
 	fprintf(fp, "             xch_nr_pages: %d (0x%x)\n",
 		xd->xc_core.header.xch_nr_pages,
 		xd->xc_core.header.xch_nr_pages);
-	fprintf(fp, "          xch_ctxt_offset: %d (0x%x)\n", 
+	fprintf(fp, "          xch_ctxt_offset: %ld (0x%lx)\n", 
 		xd->xc_core.header.xch_ctxt_offset,
 		xd->xc_core.header.xch_ctxt_offset);
-	fprintf(fp, "         xch_index_offset: %d (0x%x)\n",
+	fprintf(fp, "         xch_index_offset: %ld (0x%lx)\n",
 		xd->xc_core.header.xch_index_offset,
 		xd->xc_core.header.xch_index_offset);
-	fprintf(fp, "         xch_pages_offset: %d (0x%x)\n",
+	fprintf(fp, "         xch_pages_offset: %ld (0x%lx)\n",
 		xd->xc_core.header.xch_pages_offset,
 		xd->xc_core.header.xch_pages_offset);
 
@@ -2535,7 +2542,7 @@ xc_core_dump_Elf32_Shdr(Elf32_Off offset, int store)
 
 	if (STREQ(name, ".xen_prstatus"))
 		xd->xc_core.header.xch_ctxt_offset = 
-			(unsigned int)shdr.sh_offset;
+			(unsigned long)shdr.sh_offset;
 
 	if (STREQ(name, ".xen_shared_info"))
 		xd->xc_core.shared_info_offset = (off_t)shdr.sh_offset;
@@ -2552,7 +2559,7 @@ xc_core_dump_Elf32_Shdr(Elf32_Off offset, int store)
 
 	if (STREQ(name, ".xen_pages"))
 		xd->xc_core.header.xch_pages_offset = 
-			(unsigned int)shdr.sh_offset;
+			(unsigned long)shdr.sh_offset;
 
 	if (STREQ(name, ".xen_ia64_mapped_regs"))
 		xd->xc_core.ia64_mapped_regs_offset = 
@@ -2635,7 +2642,7 @@ xc_core_dump_Elf64_Shdr(Elf64_Off offset, int store)
 
 	if (STREQ(name, ".xen_prstatus"))
 		xd->xc_core.header.xch_ctxt_offset = 
-			(unsigned int)shdr.sh_offset;
+			(unsigned long)shdr.sh_offset;
 
 	if (STREQ(name, ".xen_shared_info"))
 		xd->xc_core.shared_info_offset = (off_t)shdr.sh_offset;
@@ -2652,7 +2659,7 @@ xc_core_dump_Elf64_Shdr(Elf64_Off offset, int store)
 
 	if (STREQ(name, ".xen_pages"))
 		xd->xc_core.header.xch_pages_offset = 
-			(unsigned int)shdr.sh_offset;
+			(unsigned long)shdr.sh_offset;
 
 	if (STREQ(name, ".xen_ia64_mapped_regs"))
 		xd->xc_core.ia64_mapped_regs_offset = 
